==> phpmd_2.6.1.orig.tar.gz: phpmd-2.6.1/src/test/php/PHPMD/Rule/ExcessivePublicCountTest.php <==
<?php
/**
 * This file is part of PHP Mess Detector.
 *
 * Copyright (c) 2008-2017, Manuel Pichler <mapi@phpmd.org>.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   * Neither the name of Manuel Pichler nor the names of his
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * @author Manuel Pichler <mapi@phpmd.org>
 * @copyright 2008-2017 Manuel Pichler. All rights reserved.
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 */

namespace PHPMD\Rule;

use PHPMD\AbstractTest;

/**
 * Test case for the excessive use of public members rule.
 *
 * @author Manuel Pichler <mapi@phpmd.org>
 * @copyright 2008-2017 Manuel Pichler. All rights reserved.
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 *
 * @covers \PHPMD\Rule\ExcessivePublicCount
 * @group phpmd
 * @group phpmd::rule
 * @group unittest
 */
class ExcessivePublicCountTest extends AbstractTest
{
    /**
     * testRuleDoesNotApplyToClassesWithLessPublicMembersThanThreshold
     *
     * @return void
     */
    public function testRuleDoesNotApplyToClassesWithLessPublicMembersThanThreshold()
    {
        $rule = new ExcessivePublicCount();
        $rule->setReport($this->getReportMock(0));
        $rule->addProperty('minimum', '42');
        $rule->apply($this->getClassMock('cis', 23));
    }

    /**
     * testRuleAppliesToClassesWithSameNumberOfPublicMembersAsThreshold
     *
     * @return void
     */
    public function testRuleAppliesToClassesWithSameNumberOfPublicMembersAsThreshold()
    {
        $rule = new ExcessivePublicCount();
        $rule->setReport($this->getReportMock(1));
        $rule->addProperty('minimum', '42');
        $rule->apply($this->getClassMock('cis', 42));
    }

    /**
     * testRuleAppliesToClassesWithMorePublicMembersThanThreshold
     *
     * @return void
     */
    public function testRuleAppliesToClassesWithMorePublicMembersThanThreshold()
    {
        $rule = new ExcessivePublicCount();
        $rule->setReport($this->getReportMock(1));
        $rule->addProperty('minimum', '23');
        $rule->apply($this->getClassMock('cis', 42));
    }
}

==> phpmd_2.8.1.orig.tar.gz: phpmd-2.8.1/src/test/php/PHPMD/Rule/ExcessivePublicCountTest.php <==
<?php
/**
 * This file is part of PHP Mess Detector.
 *
 * Copyright (c) Manuel Pichler <mapi@phpmd.org>.
 * All rights reserved.
 *
 * Licensed under BSD License
 * For full copyright and license information, please see the LICENSE file.
 * Redistributions of files must retain the above copyright notice.
 *
 * @author Manuel Pichler <mapi@phpmd.org>
 * @copyright Manuel Pichler. All rights reserved.
 * @license https://opensource.org/licenses/bsd-license.php BSD License
 * @link http://phpmd.org/
 */

namespace PHPMD\Rule;

use PHPMD\AbstractTest;

/**
 * Test case for the excessive use of public members rule.
 *
 * @covers \PHPMD\Rule\ExcessivePublicCount
 */
class ExcessivePublicCountTest extends AbstractTest
{
    /**
     * testRuleDoesNotApplyToClassesWithLessPublicMembersThanThreshold
     *
     * @return void
     */
    public function testRuleDoesNotApplyToClassesWithLessPublicMembersThanThreshold()
    {
        $rule = new ExcessivePublicCount();
        $rule->setReport($this->getReportMock(0));
        $rule->addProperty('minimum', '42');
        $rule->apply($this->getClassMock('cis', 23));
    }

    /**
     * testRuleAppliesToClassesWithSameNumberOfPublicMembersAsThreshold
     *
     * @return void
     */
    public function testRuleAppliesToClassesWithSameNumberOfPublicMembersAsThreshold()
    {
        $rule = new ExcessivePublicCount();
        $rule->setReport($this->getReportMock(1));
        $rule->addProperty('minimum', '42');
        $rule->apply($this->getClassMock('cis', 42));
    }

    /**
     * testRuleAppliesToClassesWithMorePublicMembersThanThreshold
     *
     * @return void
     */
    public function testRuleAppliesToClassesWithMorePublicMembersThanThreshold()
    {
        $rule = new ExcessivePublicCount();
        $rule->setReport($this->getReportMock(1));
        $rule->addProperty('minimum', '23');
        $rule->apply($this->getClassMock('cis', 42));
    }
}
